tonalitytools.Scale
===================

.. inheritance-diagram:: abjad.tools.tonalitytools.Scale.Scale.Scale
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.Scale.Scale.Scale

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.diatonic_interval_class_segment

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.dominant

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.inversion_equivalent_diatonic_interval_class_segment

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.key_signature

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.leading_tone

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.mediant

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.named_chromatic_pitch_class_set

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.named_chromatic_pitch_classes

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.numbered_chromatic_pitch_class_segment

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.numbered_chromatic_pitch_class_set

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.numbered_chromatic_pitch_classes

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.subdominant

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.submediant

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.superdominant

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.tonic

Methods
-------

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.count

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.create_named_chromatic_pitch_set_in_pitch_range

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.index

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.is_equivalent_under_transposition

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.named_chromatic_pitch_class_to_scale_degree

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.retrograde

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.rotate

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.scale_degree_to_named_chromatic_pitch_class

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.transpose

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__add__

   .. note:: Inherited from :py:class:`pitchtools._Segment <abjad.tools.pitchtools._Segment._Segment._Segment>`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__contains__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__eq__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__ge__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__getitem__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__getslice__

   .. note:: Inherited from :py:class:`pitchtools._Segment <abjad.tools.pitchtools._Segment._Segment._Segment>`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__gt__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__hash__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__iter__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__le__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__len__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__lt__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__mul__

   .. note:: Inherited from :py:class:`pitchtools._Segment <abjad.tools.pitchtools._Segment._Segment._Segment>`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__ne__

   .. note:: Inherited from `__builtin__.tuple`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__repr__

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__rmul__

   .. note:: Inherited from :py:class:`pitchtools._Segment <abjad.tools.pitchtools._Segment._Segment._Segment>`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__str__

   .. note:: Inherited from :py:class:`pitchtools.NamedChromaticPitchClassSegment <abjad.tools.pitchtools.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment.NamedChromaticPitchClassSegment>`
